==> vue-components-1.5.13.tgz: package/lib/spinners/src/Spinner.vue.rd.js <==
import { defineComponent as h, toRefs as m, computed as s, openBlock as i, createElementBlock as a, normalizeStyle as l, unref as t, createElementVNode as r, normalizeClass as x, createCommentVNode as f } from "vue";
import { spinnerProps as _ } from "./props.rd.js";
const w = {
  key: 0,
  xmlns: "http://www.w3.org/2000/svg",
  width: "100%",
  height: "100%",
  viewBox: "0 0 100 100",
  preserveAspectRatio: "xMidYMid",
  class: "uil-ring-alt"
}, y = /* @__PURE__ */ r("rect", {
  x: "0",
  y: "0",
  width: "100",
  height: "100",
  fill: "none",
  class: "bk"
}, null, -1), g = /* @__PURE__ */ r("animate", {
  attributeName: "stroke-dashoffset",
  dur: "2s",
  repeatCount: "indefinite",
  from: "0",
  to: "-502"
}, null, -1), k = /* @__PURE__ */ r("animate", {
  attributeName: "stroke-dasharray",
  dur: "2s",
  repeatCount: "indefinite",
  values: "150.6 100.4;1 250;150.6 100.4"
}, null, -1), v = [
  g,
  k
], S = /* @__PURE__ */ h({
  __name: "Spinner",
  props: _(),
  setup(c) {
    const n = c, { loading: u, size: e, inherit: d } = m(n), p = s(() => e != null && e.value ? { width: `${e.value}px`, height: `${e.value}px` } : { width: "20px", height: "20px" }), o = s(() => {
      if (d.value)
        return "";
      switch (n.color) {
        case "light":
          return "text-white";
        case "primary":
          return "text-primary-700 dark:text-primary-500";
        case "secondary":
          return "text-secondary-400";
        case "danger":
          return "text-rose-400";
        case "warning":
          return "text-yellow-300";
      }
    });
    return (C, N) => (i(), a("div", {
      style: l(t(p))
    }, [
      t(u) ? (i(), a("svg", w, [
        y,
        r("circle", {
          cx: "50",
          cy: "50",
          r: "40",
          class: x(["stroke-current", t(o)]),
          fill: "none",
          "stroke-width": "13",
          "stroke-linecap": "round",
          style: l({ color: t(o) })
        }, v, 6)
      ])) : f("", !0)
    ], 4));
  }
});
export {
  S as default
};

==> vue-components-1.6.6.tgz: package/lib/spinners/src/Spinner.vue.rd.js <==
import { defineComponent as h, toRefs as m, computed as s, openBlock as i, createElementBlock as a, normalizeStyle as l, unref as t, createElementVNode as r, normalizeClass as x, createCommentVNode as f } from "vue";
import { spinnerProps as _ } from "./props.rd.js";
const w = {
  key: 0,
  xmlns: "http://www.w3.org/2000/svg",
  width: "100%",
  height: "100%",
  viewBox: "0 0 100 100",
  preserveAspectRatio: "xMidYMid",
  class: "uil-ring-alt"
}, y = /* @__PURE__ */ r("rect", {
  x: "0",
  y: "0",
  width: "100",
  height: "100",
  fill: "none",
  class: "bk"
}, null, -1), g = /* @__PURE__ */ r("animate", {
  attributeName: "stroke-dashoffset",
  dur: "2s",
  repeatCount: "indefinite",
  from: "0",
  to: "-502"
}, null, -1), k = /* @__PURE__ */ r("animate", {
  attributeName: "stroke-dasharray",
  dur: "2s",
  repeatCount: "indefinite",
  values: "150.6 100.4;1 250;150.6 100.4"
}, null, -1), v = [
  g,
  k
], S = /* @__PURE__ */ h({
  __name: "Spinner",
  props: _(),
  setup(c) {
    const n = c, { loading: u, size: e, inherit: d } = m(n), p = s(() => e != null && e.value ? { width: `${e.value}px`, height: `${e.value}px` } : { width: "20px", height: "20px" }), o = s(() => {
      if (d.value)
        return "";
      switch (n.color) {
        case "light":
          return "text-white";
        case "primary":
          return "!text-primary-700 dark:!text-primary-500";
        case "secondary":
          return "text-secondary-400";
        case "danger":
          return "text-rose-400";
        case "warning":
          return "text-yellow-300";
      }
    });
    return (C, N) => (i(), a("div", {
      style: l(t(p))
    }, [
      t(u) ? (i(), a("svg", w, [
        y,
        r("circle", {
          cx: "50",
          cy: "50",
          r: "40",
          class: x(["stroke-current", t(o)]),
          fill: "none",
          "stroke-width": "13",
          "stroke-linecap": "round",
          style: l({ color: t(o) })
        }, v, 6)
      ])) : f("", !0)
    ], 4));
  }
});
export {
  S as default
};
